@@ -56,12 +56,16 @@ from utilities.math import (
     MAX_FLOAT64,
     MAX_INT32,
     MAX_INT64,
+    MAX_UINT8,
+    MAX_UINT16,
     MAX_UINT32,
     MAX_UINT64,
     MIN_FLOAT32,
     MIN_FLOAT64,
     MIN_INT32,
     MIN_INT64,
+    MIN_UINT8,
+    MIN_UINT16,
     MIN_UINT32,
     MIN_UINT64,
     is_zero,
@@ -176,14 +180,14 @@ def date_deltas(
             min_value_ = DATE_DELTA_MIN
         case DateDelta():
             ...
-        case _ as never:
+        case never:
             assert_never(never)
     match max_value_:
         case None:
             max_value_ = DATE_DELTA_MAX
         case DateDelta():
             ...
-        case _ as never:
+        case never:
             assert_never(never)
     min_days = to_days(min_value_)
     max_days = to_days(max_value_)
@@ -213,14 +217,14 @@ def date_time_deltas(
             min_value_ = DATE_TIME_DELTA_MIN
         case DateTimeDelta():
             ...
-        case _ as never:
+        case never:
             assert_never(never)
     match max_value_:
         case None:
             max_value_ = DATE_TIME_DELTA_MAX
         case DateTimeDelta():
             ...
-        case _ as never:
+        case never:
             assert_never(never)
     min_nanos, max_nanos = map(to_nanoseconds, [min_value_, max_value_])
     if draw2(draw, parsable):
@@ -249,14 +253,14 @@ def dates(
             min_value_ = Date.MIN
         case Date():
             ...
-        case _ as never:
+        case never:
             assert_never(never)
     match max_value_:
         case None:
             max_value_ = Date.MAX
         case Date():
             ...
-        case _ as never:
+        case never:
             assert_never(never)
     if draw2(draw, two_digit):
         min_value_ = max(min_value_, DATE_TWO_DIGIT_YEAR_MIN)
@@ -339,7 +343,7 @@ def draw2[T](
             raise _Draw2InputResolvedToSentinelError
         case _, _, _:
             return value
-        case _ as never:
+        case never:
             assert_never(never)
 
 
@@ -668,14 +672,14 @@ def month_days(
             min_value_ = MonthDay.MIN
         case MonthDay():
             ...
-        case _ as never:
+        case never:
             assert_never(never)
     match max_value_:
         case None:
             max_value_ = MonthDay.MAX
         case MonthDay():
             ...
-        case _ as never:
+        case never:
             assert_never(never)
     min_date, max_date = [m.in_year(2000) for m in [min_value_, max_value_]]
     date = draw(dates(min_value=min_date, max_value=max_date))
@@ -790,14 +794,14 @@ def plain_datetimes(
             min_value_ = PlainDateTime.MIN
         case PlainDateTime():
             ...
-        case _ as never:
+        case never:
             assert_never(never)
     match max_value_:
         case None:
             max_value_ = PlainDateTime.MAX
         case PlainDateTime():
             ...
-        case _ as never:
+        case never:
             assert_never(never)
     py_datetime = draw(
         datetimes(
@@ -836,7 +840,7 @@ def random_states(
     """Strategy for generating `numpy` random states."""
     from numpy.random import RandomState
 
-    seed_ = draw2(draw, seed, integers(0, MAX_UINT32))
+    seed_ = draw2(draw, seed, uint32s())
     return RandomState(seed=seed_)
 
 
@@ -883,7 +887,7 @@ def setup_hypothesis_profiles(
                     return 100
                 case Profile.ci:
                     return 1000
-                case _ as never:
+                case never:
                     assert_never(never)
 
         @property
@@ -893,7 +897,7 @@ def setup_hypothesis_profiles(
                     return Verbosity.quiet
                 case Profile.ci:
                     return Verbosity.verbose
-                case _ as never:
+                case never:
                     assert_never(never)
 
     phases = {Phase.explicit, Phase.reuse, Phase.generate, Phase.target}
@@ -1150,14 +1154,14 @@ def time_deltas(
             min_value_ = TIME_DELTA_MIN
         case TimeDelta():
             ...
-        case _ as never:
+        case never:
             assert_never(never)
     match max_value_:
         case None:
             max_value_ = TIME_DELTA_MAX
         case TimeDelta():
             ...
-        case _ as never:
+        case never:
             assert_never(never)
     py_time = draw(
         hypothesis.strategies.timedeltas(
@@ -1185,14 +1189,14 @@ def times(
             min_value_ = Time.MIN
         case Time():
             ...
-        case _ as never:
+        case never:
             assert_never(never)
     match max_value_:
         case None:
             max_value_ = Time.MAX
         case Time():
             ...
-        case _ as never:
+        case never:
             assert_never(never)
     py_time = draw(
         hypothesis.strategies.times(
@@ -1226,6 +1230,36 @@ def _triples_map[T](elements: list[T], /) -> tuple[T, T, T]:
 ##
 
 
+@composite
+def uint8s(
+    draw: DrawFn,
+    /,
+    *,
+    min_value: MaybeSearchStrategy[int] = MIN_UINT8,
+    max_value: MaybeSearchStrategy[int] = MAX_UINT8,
+) -> int:
+    """Strategy for generating uint8s."""
+    min_value_, max_value_ = [draw2(draw, v) for v in [min_value, max_value]]
+    min_value_ = max(min_value_, MIN_UINT8)
+    max_value_ = min(max_value_, MAX_UINT8)
+    return draw(integers(min_value=min_value_, max_value=max_value_))
+
+
+@composite
+def uint16s(
+    draw: DrawFn,
+    /,
+    *,
+    min_value: MaybeSearchStrategy[int] = MIN_UINT16,
+    max_value: MaybeSearchStrategy[int] = MAX_UINT16,
+) -> int:
+    """Strategy for generating uint16s."""
+    min_value_, max_value_ = [draw2(draw, v) for v in [min_value, max_value]]
+    min_value_ = max(min_value_, MIN_UINT16)
+    max_value_ = min(max_value_, MAX_UINT16)
+    return draw(integers(min_value=min_value_, max_value=max_value_))
+
+
 @composite
 def uint32s(
     draw: DrawFn,
@@ -1322,14 +1356,14 @@ def year_months(
             min_value_ = YearMonth.MIN
         case YearMonth():
             ...
-        case _ as never:
+        case never:
             assert_never(never)
     match max_value_:
         case None:
             max_value_ = YearMonth.MAX
         case YearMonth():
             ...
-        case _ as never:
+        case never:
             assert_never(never)
     min_date, max_date = [m.on_day(1) for m in [min_value_, max_value_]]
     date = draw(dates(min_value=min_date, max_value=max_date, two_digit=two_digit))
@@ -1357,7 +1391,7 @@ def zoned_datetimes(
         case ZonedDateTime():
             with assume_does_not_raise(ValueError):
                 min_value_ = min_value_.to_tz(time_zone_.key).to_plain()
-        case _ as never:
+        case never:
             assert_never(never)
     match max_value_:
         case None | PlainDateTime():
@@ -1365,7 +1399,7 @@ def zoned_datetimes(
         case ZonedDateTime():
             with assume_does_not_raise(ValueError):
                 max_value_ = max_value_.to_tz(time_zone_.key).to_plain()
-        case _ as never:
+        case never:
             assert_never(never)
     plain = draw(plain_datetimes(min_value=min_value_, max_value=max_value_))
     with (
@@ -1381,6 +1415,11 @@ def zoned_datetimes(
     return zoned
 
 
+zoned_datetimes_2000 = zoned_datetimes(
+    min_value=ZonedDateTime(2000, 1, 1, tz=UTC.key),
+    max_value=ZonedDateTime(2000, 12, 31, tz=UTC.key),
+)
+
 __all__ = [
     "Draw2Error",
     "MaybeSearchStrategy",
@@ -1426,10 +1465,13 @@ __all__ = [
     "time_deltas",
     "times",
     "triples",
+    "uint8s",
+    "uint16s",
     "uint32s",
     "uint64s",
     "urls",
     "versions",
     "year_months",
     "zoned_datetimes",
+    "zoned_datetimes_2000",
 ]
